#!/bin/bash
exit_identification() {
	echo "$(date) The identification of sample $1 returned an error. Check the stderr of this sample $2."
	echo "$(date) The identification of sample $1 returned an error. Check the stderr of this sample $2." >> $3
	exit
}
exit_other() {
	echo "$(date) The last file generated contains an error. Check the file $1"
	echo "$(date) The last file generated contains an error. Check the file $1" >> $2
	exit
}


init=$1
. $init
now=$(date)
echo "Launching iterative identification identification $now output=${output_d} param=${param_d}"
mkdir -p ${output_d}
mkdir -p ${params_d}



##### Creating combined fasta file for the samples

echo "$(date) Reading files and creation of combined database from step2"
echo "$(date) Reading files and creation of combined database from step2" >> ${params_d}/$stdout
# the zero mean : its not a classical identification ; the second zero mean : its the second step
metapappso_reading.sh $evalue ${output_d} ${job_name} 0 0 
tmp=$( tail -1 ${output_d}/combined_second_step_${job_name}_read.xml)
if [[ $tmp == '</peptide_result>' ]]
then
	metapappso_create_fasta_enhanced.py -x ${output_d}/combined_second_step_${job_name}_read.xml -f ${database_d}/${metahit_f} -o ${output_d}/combined_proteome_${job_name}.fasta
else
        exit_other "${output_d}/combined_second_step_${job_name}_read.xml" $stderr 
fi


echo "$(date) Combined database has been created"
echo "$(date) Combined database has been created" >> ${params_d}/$stdout

####################################
############ THIRD STEP ############
####################################




echo -e "Universe   = vanilla\nnotification   = Error\nRank       = Mips\nrequest_memory= ${request_memory}\nrequest_cpus = ${request_cpus}\nExecutable = ${tandem_bin}\nLog        = ${params_d}/htcondor_step_3_${job_name}.log\nOutput        = ${params_d}/htcondor_step_3_${job_name}.\$(Process).out\nError        = ${params_d}/htcondor_step_3_${job_name}.\$(Process).error\n" > ${params_d}/htcondor_step_3_${job_name}.submit



echo "$(date) Third step of identification starts" >> ${params_d}/$stdout
echo "$(date) Third step of identification starts"
# create database for third step
echo -e "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<bioml label=\"x! taxon-to-file matching list\">\n<taxon label=\"usedefined\">\n<file format=\"peptide\" URL=\"${database_d}/${human_f}\"></file>\n<file format=\"peptide\" URL=\"${database_d}/${conta_f}\"></file>\n<file format=\"peptide\" URL=\"${output_d}/combined_proteome_${job_name}.fasta\"></file>\n</taxon>\n</bioml>" > ${params_d}/xtandem_database_third_step_${job_name}.database

for sample in $(cat ${list_samples_path})
do
        if [ -f ${output_d}/${sample}_third_step_${job_name}.xml ]
        then
                echo "$(date) The third step of sample $sample has already been identified. Pass to next sample." >> ${params_d}/$stdout
        else
        	# create parameter files specific to the samples
		echo -e "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<bioml label=\"${sample}_${job_name}_third_step.xml\">\n<note type=\"heading\">Paths</note>\n<note type=\"input\" label=\"list path, default parameters\">${models_d}/${model_third_f}</note>\n<note type=\"input\" label=\"list path, taxonomy information\">${params_d}/xtandem_database_third_step_${job_name}.database</note>\n<note type=\"input\" label=\"spectrum, path\">${spectra_d}/${sample}.${spectra_extension}</note>\n<note type=\"heading\">Protein general</note>\n<note type=\"input\" label=\"protein, taxon\">usedefined</note>\n<note type=\"heading\">Output</note>\n<note type=\"input\" label=\"output, path\">${output_d}/${sample}_third_step_${job_name}.xml</note>\n</bioml>" > ${params_d}/xtandem_param_${sample}_third_step_${job_name}.param
                # launching third step
                echo -e "Arguments        = ${params_d}/xtandem_param_${sample}_third_step_${job_name}.param\nQueue\n" >> ${params_d}/htcondor_step_3_${job_name}.submit
	fi
done

echo "$(date) Third step of identification is over"
echo "$(date) Third step of identification is over" >> ${params_d}/$stdout


/usr/bin/condor_submit ${params_d}/htcondor_step_3_${job_name}.submit
