#!/bin/bash
exit_identification() {
	echo "$(date) The identification of sample $1 returned an error. Check the stderr of this sample $2."
	echo "$(date) The identification of sample $1 returned an error. Check the stderr of this sample $2." >> $3
	exit
}
exit_other() {
	echo "$(date) The last file generated contains an error. Check the file $1"
	echo "$(date) The last file generated contains an error. Check the file $1" >> $2
	exit
}


init=$1
. $init
now=$(date)
echo "Launching iterative identification identification $now"
mkdir -p ${output_d}
mkdir -p ${params_d}
mounts="${spectra_d}:/data/spectra,${models_d}:/data/models,${database_d}:/data/database,${params_d}:/data/params,${output_d}:/data/output ${container}"



#################
### initialization
################

#creating database file for first step
echo -e "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<bioml label=\"x! taxon-to-file matching list\">\n<taxon label=\"usedefined\">\n<file format=\"peptide\" URL=\"/data/database/${human_f}\"></file>\n<file format=\"peptide\" URL=\"/data/database/${conta_f}\"></file>\n<file format=\"peptide\" URL=\"/data/database/${metahit_f}\"></file>\n</taxon>\n</bioml>" > ${params_d}/xtandem_database_first_step_${job_name}.database

#writing variables in stdout
echo -e "Workflow variables for iterative identification:\n list_samples : ${list_samples_path} \n stdout : $stdout \n stderr : $stderr \n params_dir : ${params_d} \n evalue : $evalue \n job_name : ${job_name} \n model first step : ${model_d}/${model_first_f} \n model second step : ${model_d}/${model_second_f} \n model third step : ${model_d}/${model_third_f} \n mzXML path : ${spectra_d} \n metahit_path : ${database_d}/${metahit_f} \n human_path : ${database_d}/${human_f} \n conta_path : ${database_d}/${conta_f} \n" >> ${params_d}/$stdout


####################################
############ FIRST STEP ############
####################################

echo "First step of identification" >> ${params_d}/$stdout

################
### working in loop with files
################

for sample in $(cat ${list_samples_path})
do
	if [ -f ${output_d}/${sample}_first_step_${job_name}.xml ]
	then
		echo "$(date) The first step of sample $sample has already been identified. Pass to next sample." >> ${params_d}/$stdout
	else
		#create .param for first step
		echo -e "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<bioml label=\"${sample}_first_step_${job_name}.xml\">\n<note type=\"heading\">Paths</note>\n<note type=\"input\" label=\"list path, default parameters\">/data/models/${model_first_f}</note>\n<note type=\"input\" label=\"list path, taxonomy information\">/data/params/xtandem_database_first_step_${job_name}.database</note>\n<note type=\"input\" label=\"spectrum, path\">/data/spectra/${sample}.mzXML</note>\n<note type=\"heading\">Protein general</note>\n<note type=\"input\" label=\"protein, taxon\">usedefined</note>\n<note type=\"heading\">Output</note>\n<note type=\"input\" label=\"output, path\">/data/output/${sample}_first_step_${job_name}.xml</note>\n</bioml>" > ${params_d}/xtandem_param_${sample}_first_step_${job_name}.param
		#create specific standard error/output for the sample
		stderr_sample=${params_d}/tandem_${sample}_first_step_${job_name}.error
		stdout_sample=${params_d}/tandem_${sample}_first_step_${job_name}.out
		touch ${stderr_sample}
		touch ${stdout_sample}
		echo "$(date) Sample treated for first step: $sample"
		echo "$(date) Sample treated for first step: $sample" >> ${params_d}/$stdout
		# launching first step
		singularity exec -B ${mounts} tandem /data/params/xtandem_param_${sample}_first_step_${job_name}.param > ${stdout_sample} 2> ${stderr_sample}
		echo "$(date) First step of identification is over for $sample"
		echo "$(date) First step of identification is over for $sample" >> ${params_d}/$stdout
		if [[ -s $stderr_sample ]] # si le stderr est non vide
    		then
       			exit_identification $sample $stderr_sample $stderr 
		fi
	fi
done
echo "$(date) First step of identification is over"
echo "$(date) First step of identification is over" >> ${params_d}/$stdout

##### Creating specific fasta files for the samples

echo "$(date) Creation of specific databases"
echo "$(date) Creation of specific databases" >> ${params_d}/$stdout
for sample in $(cat ${list_samples_path})
do
	echo "$(date) Start reading result for $sample" >> ${params_d}/$stdout
	singularity exec -B ${mounts} gp-read-xtandem.py -e 10000 -o /data/output/${sample}_first_step_${job_name}_read.xml  /data/output/${sample}_first_step_${job_name}.xml
	tmp=$( tail -1 ${output_d}/${sample}_first_step_${job_name}_read.xml)
	if [[ $tmp == '</peptide_result>' ]]
	then
		echo "$(date) Start creating specific database of $sample" >> ${params_d}/$stdout
		singularity exec -B ${mounts} python /data/default/scripts/create_fasta_enhanced.py -x /data/output/${sample}_first_step_${job_name}_read.xml -f /data/database/${metahit_f} -o /data/output/${sample}_metaproteome_${job_name}.fasta
	else
		exit_other "${output_d}/${sample}_first_step_${job_name}_read.xml" $stderr 
	fi
done
echo "$(date) Specific databases have been created"
echo "$(date) Specific databases have been created" >> ${params_d}/$stdout

####################################
############ SECOND STEP ############
####################################

echo "$(date) Second step of identification starts" >> ${params_d}/$stdout
echo "$(date) Second step of identification starts"
for sample in $(cat ${list_samples_path})
do
	if [ -f ${output_d}/${sample}_second_step_${job_name}.xml ]
	then
		echo "$(date) The second step of sample $sample has already been identified. Pass to next sample." >> ${params_d}/$stdout
	else
 		# create databases and parameter file specific to the samples
		echo -e "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<bioml label=\"x! taxon-to-file matching list\">\n<taxon label=\"usedefined\">\n<file format=\"peptide\" URL=\"/data/database/${human_f}\"></file>\n<file format=\"peptide\" URL=\"/data/database/${conta_f}\"></file>\n<file format=\"peptide\" URL=\"/data/output/${sample}_metaproteome_${job_name}.fasta\"></file>\n</taxon>\n</bioml>" > ${params_d}/xtandem_database_${sample}_second_step_${job_name}.database
		echo -e "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<bioml label=\"${sample}_second_step_${job_name}.xml\">\n<note type=\"heading\">Paths</note>\n<note type=\"input\" label=\"list path, default parameters\">/data/models/${model_second_f}</note>\n<note type=\"input\" label=\"list path, taxonomy information\">/data/params/xtandem_database_${sample}_second_step_${job_name}.database</note>\n<note type=\"input\" label=\"spectrum, path\">/data/spectra/${sample}.mzXML</note>\n<note type=\"heading\">Protein general</note>\n<note type=\"input\" label=\"protein, taxon\">usedefined</note>\n<note type=\"heading\">Output</note>\n<note type=\"input\" label=\"output, path\">/data/output/${sample}_second_step_${job_name}.xml</note>\n</bioml>" > ${params_d}/xtandem_param_${sample}_second_step_${job_name}.param
		#create specific standard error/output for the sample
                stderr_sample=${params_d}/tandem_${sample}_second_step_${job_name}.error
                stdout_sample=${params_d}/tandem_${sample}_second_step_${job_name}.out
                touch ${stderr_sample}
                touch ${stdout_sample}
                echo "$(date) Sample treated for second step: $sample"
                echo "$(date) Sample treated for second step: $sample" >> ${params_d}/$stdout
                # launching second step
                singularity exec -B ${mounts} tandem /data/params/xtandem_param_${sample}_second_step_${job_name}.param > ${stdout_sample} 2> ${stderr_sample}
                echo "$(date) Second step of identification is over for $sample"
                echo "$(date) Second step of identification is over for $sample" >> ${params_d}/$stdout
                if [[ -s $stderr_sample ]] # si le stderr est non vide
                then
                        exit_identification $sample $stderr_sample $stderr 
                fi
	fi
done

echo "$(date) Second step of identification is over"
echo "$(date) Second step of identification is over" >> ${params_d}/$stdout

##### Creating combined fasta file for the samples

echo "$(date) Reading files and creation of combined database"
echo "$(date) Reading files and creation of combined database" >> ${params_d}/$stdout
# the zero mean : its not a classical identification ; the second zero mean : its the second step
singularity exec -B ${mounts} /data/default/scripts/reading.sh $evalue /data/output ${job_name} 0 0 
tmp=$( tail -1 ${output_d}/combined_second_step_${job_name}_read.xml)
if [[ $tmp == '</peptide_result>' ]]
then
	singularity exec -B ${mounts} python /data/default/scripts/create_fasta_enhanced.py -x /data/output/combined_second_step_${job_name}_read.xml -f /data/database/${metahit_f} -o /data/output/combined_proteome_${job_name}.fasta
else
        exit_other "${output_d}/combined_second_step_${job_name}_read.xml" $stderr 
fi


echo "$(date) Combined database has been created"
echo "$(date) Combined database has been created" >> ${params_d}/$stdout

####################################
############ THIRD STEP ############
####################################

echo "$(date) Third step of identification starts" >> ${params_d}/$stdout
echo "$(date) Third step of identification starts"
# create database for third step
echo -e "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<bioml label=\"x! taxon-to-file matching list\">\n<taxon label=\"usedefined\">\n<file format=\"peptide\" URL=\"/data/database/${human_f}\"></file>\n<file format=\"peptide\" URL=\"/data/database/${conta_f}\"></file>\n<file format=\"peptide\" URL=\"/data/output/combined_proteome_${job_name}.fasta\"></file>\n</taxon>\n</bioml>" > ${params_d}/xtandem_database_third_step_${job_name}.database

for sample in $(cat ${list_samples_path})
do
        if [ -f ${output_d}/${sample}_third_step_${job_name}.xml ]
        then
                echo "$(date) The third step of sample $sample has already been identified. Pass to next sample." >> ${params_d}/$stdout
        else
        	# create parameter files specific to the samples
		echo -e "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<bioml label=\"${sample}_${job_name}_third_step.xml\">\n<note type=\"heading\">Paths</note>\n<note type=\"input\" label=\"list path, default parameters\">/data/models/${model_third_f}</note>\n<note type=\"input\" label=\"list path, taxonomy information\">/data/params/xtandem_database_third_step_${job_name}.database</note>\n<note type=\"input\" label=\"spectrum, path\">/data/spectra/${sample}.mzXML</note>\n<note type=\"heading\">Protein general</note>\n<note type=\"input\" label=\"protein, taxon\">usedefined</note>\n<note type=\"heading\">Output</note>\n<note type=\"input\" label=\"output, path\">/data/output/${sample}_third_step_${job_name}.xml</note>\n</bioml>" > ${params_d}/xtandem_param_${sample}_third_step_${job_name}.param
		stderr_sample=${params_d}/tandem_${sample}_third_step_${job_name}.error
                stdout_sample=${params_d}/tandem_${sample}_third_step_${job_name}.out
                touch ${stderr_sample}
                touch ${stdout_sample}
                echo "$(date) Sample treated for third step: $sample"
                echo "$(date) Sample treated for third step: $sample" >> ${params_d}/$stdout
                # launching third step
                singularity exec -B ${mounts} tandem /data/params/xtandem_param_${sample}_third_step_${job_name}.param > ${stdout_sample} 2> ${stderr_sample}
                echo "$(date) Third step of identification is over for $sample"
                echo "$(date) Third step of identification is over for $sample" >> ${params_d}/$stdout
                if [[ -s $stderr_sample ]] # si le stderr est non vide
                then
                        exit_identification $sample $stderr_sample $stderr
                fi
	fi
done

echo "$(date) Third step of identification is over"
echo "$(date) Third step of identification is over" >> ${params_d}/$stdout


##############
### Read and group files
#############

echo "$(date) All identifications are over, start reading results" >> ${params_d}/$stdout
echo "$(date) All identifications are over, start reading results"
# zero : its an iterative interrogation ; one: its the third step
singularity exec -B ${mounts} /data/default/scripts/reading.sh ${evalue} /data/output ${job_name} 0 1
echo "$(date) Start grouping" >> ${params_d}/$stdout
echo "$(date) Start grouping" 
singularity exec -B ${mounts} gp-grouping -i /data/output/combined_third_step_${job_name}_read.xml -o /data/output/grouping_${job_name}.xml --decoy-regexp "(^conta\|.*|.*\|reversed$)"
singularity exec -B ${mounts} gp-output-peptide-counting.py -i /data/output/grouping_${job_name}.xml -o /data/output/peptide_counting_${job_name}.txt
singularity exec -B ${mounts} gp-output-peptide-list.py -i /data/output/grouping_${job_name}.xml -o /data/output/peptide_list_${job_name}.txt
singularity exec -B ${mounts} gp-output-protein-counting.py -i /data/output/grouping_${job_name}.xml -o /data/output/protein_counting_${job_name}.txt
singularity exec -B ${mounts} gp-output-protein-list.py -i /data/output/grouping_${job_name}.xml -o /data/output/protein_list_${job_name}.txt
singularity exec -B ${mounts} gp-fdr-peptide -i /data/output/read_${job_name}.xml -o /data/output/FDR_${job_name}.txt
echo "$(date) Read and grouping are over" >> ${params_d}/$stdout
echo "$(date) Read and grouping are over"
