#!/bin/bash
init=$1
. $init
now=$(date)
echo "Launching classical identification $now" 
mkdir -p ${output_d}
mkdir -p ${params_d}
#mounts="${spectra_d}:/data/spectra,${models_d}:/data/models,${database_d}:/data/database,${params_d}:/data/params,${output_d}:/data/output ${container}"

#################
### initialization
################

#creating database file
echo -e "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<bioml label=\"x! taxon-to-file matching list\">\n<taxon label=\"usedefined\">\n<file format=\"peptide\" URL=\"${database_d}/${human_f}\"></file>\n<file format=\"peptide\" URL=\"${database_d}/${conta_f}\"></file>\n<file format=\"peptide\" URL=\"${database_d}/${metahit_f}\"></file>\n</taxon>\n</bioml>" > ${params_d}/xtandem_database_${job_name}.database

#writing variables in stdout
echo -e "Workflow variables for classical identification:\n list_samples : ${list_samples_path} \n stdout : $stdout \n stderr : $stderr \n params_dir : ${params_d} \n evalue : $evalue \n job_name : ${job_name} \n model : ${model_d}/${model} \n mzXML path : ${spectra_d} \n metahit_path : ${database_d}${metahit_f} \n human_path : ${database_d}/${human_f} \n conta_path : ${database_d}/${conta_f} \n" >> ${params_d}/$stdout

################
### working in loop with files
################

for sample in $(cat ${list_samples_path})
do
	if [ -f ${output_d}/${sample}_${job_name}.xml ]
	then
		echo "$(date) The sample $sample has already been identified. Pass to next sample." >> ${params_d}/$stdout
	else
		#create .param for identification
		echo -e "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<bioml label=\"${sample}_${job_name}.xml\">\n<note type=\"heading\">Paths</note>\n<note type=\"input\" label=\"list path, default parameters\">${models_d}/${model}</note>\n<note type=\"input\" label=\"list path, taxonomy information\">${params_d}/xtandem_database_${job_name}.database</note>\n<note type=\"input\" label=\"spectrum, path\">${spectra_d}/${sample}.mzXML</note>\n<note type=\"heading\">Protein general</note>\n<note type=\"input\" label=\"protein, taxon\">usedefined</note>\n<note type=\"heading\">Output</note>\n<note type=\"input\" label=\"output, path\">${output_d}/${sample}_${job_name}.xml</note>\n</bioml>" > ${params_d}/xtandem_param_${sample}_${job_name}.param
		#create specific standard error/output for the sample
		stderr_sample=${params_d}/tandem_${sample}_${job_name}.error
		stdout_sample=${params_d}/tandem_${sample}_${job_name}.out
		touch ${stderr_sample}
		touch ${stdout_sample}
		echo "$(date) Sample treated: $sample"
		echo "$(date) Sample treated: $sample" >> ${params_d}/$stdout
		# launching identificartion
		tandem ${params_d}/xtandem_param_${sample}_${job_name}.param > ${stdout_sample} 2> ${stderr_sample}
		echo "$(date) Identification is over for $sample"
		echo "$(date) Identification is over for $sample" >> ${params_d}/$stdout
		if [[ -s $stderr_sample ]] # si le stderr est non vide
    		then
       			echo "$(date) WARNING : Stderr is not empty for ${sample}."
       			echo "$(date) WARNING : Stderr is not empty for ${sample}." >> ${params_d}/$stderr
		fi
	fi
done

##############
### Read and group files
#############

echo "$(date) All identifications are over, start reading results" >> ${params_d}/$stdout
echo "$(date) All identifications are over, start reading results"
metapappso_reading.sh ${evalue} ${output_d} ${job_name} 1
echo "$(date) Start grouping" >> ${params_d}/$stdout
echo "$(date) Start grouping" 
gp-grouping -i ${output_d}/read_${job_name}.xml -o ${output_d}/grouping_${job_name}.xml --decoy-regexp "(^conta\|.*|.*\|reversed$)"
gp-output-peptide-counting.py -i ${output_d}/grouping_${job_name}.xml -o ${output_d}/peptide_counting_${job_name}.txt
gp-output-peptide-list.py -i ${output_d}/grouping_${job_name}.xml -o ${output_d}/peptide_list_${job_name}.txt
gp-output-protein-counting.py -i ${output_d}/grouping_${job_name}.xml -o ${output_d}/protein_counting_${job_name}.txt
gp-output-protein-list.py -i ${output_d}/grouping_${job_name}.xml -o ${output_d}/protein_list_${job_name}.txt
gp-fdr-peptide -i ${output_d}/read_${job_name}.xml -o ${output_d}/FDR_${job_name}.txt
echo "$(date) Read and grouping are over" >> ${params_d}/$stdout
echo "$(date) Read and grouping are over"
