#!/bin/bash
exit_identification() {
	echo "$(date) The identification of sample $1 returned an error. Check the stderr of this sample $2."
	echo "$(date) The identification of sample $1 returned an error. Check the stderr of this sample $2." >> $3
	exit
}
exit_other() {
	echo "$(date) The last file generated contains an error. Check the file $1"
	echo "$(date) The last file generated contains an error. Check the file $1" >> $2
	exit
}


init=$1
. $init
now=$(date)
echo "Launching iterative identification identification $now output=${output_d} param=${param_d}"
mkdir -p ${output_d}
mkdir -p ${params_d}
#mounts="${spectra_d}:/data/spectra,${models_d}:/data/models,${database_d}:/data/database,${params_d}:/data/params,${output_d}:/data/output ${container}"



#################
### initialization
################

#creating database file for first step
echo -e "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<bioml label=\"x! taxon-to-file matching list\">\n<taxon label=\"usedefined\">\n<file format=\"peptide\" URL=\"${database_d}/${human_f}\"></file>\n<file format=\"peptide\" URL=\"${database_d}/${conta_f}\"></file>\n<file format=\"peptide\" URL=\"${database_d}/${metahit_f}\"></file>\n</taxon>\n</bioml>" > ${params_d}/xtandem_database_first_step_${job_name}.database

#writing variables in stdout
echo -e "Workflow variables for iterative identification:\n list_samples : ${list_samples_path} \n stdout : $stdout \n stderr : $stderr \n params_dir : ${params_d} \n evalue : $evalue \n job_name : ${job_name} \n model first step : ${model_d}/${model_first_f} \n model second step : ${model_d}/${model_second_f} \n model third step : ${model_d}/${model_third_f} \n mzXML path : ${spectra_d} \n metahit_path : ${database_d}/${metahit_f} \n human_path : ${database_d}/${human_f} \n conta_path : ${database_d}/${conta_f} \n" >> ${params_d}/$stdout


####################################
############ FIRST STEP ############
####################################

echo "First step of identification" >> ${params_d}/$stdout

################
### working in loop with files
################


echo -e "Universe   = vanilla\nnotification   = Error\nRank       = Mips\nrequest_memory= ${request_memory}\nrequest_cpus = ${request_cpus}\nExecutable = ${tandem_bin}\nLog        = ${params_d}/htcondor_step_1_${job_name}.log\nOutput        = ${params_d}/htcondor_step_1_${job_name}.\$(Process).out\nError        = ${params_d}/htcondor_step_1_${job_name}.\$(Process).error\n" > /tmp/test.submit
		

for sample in $(cat ${list_samples_path})
do
	if [ -f ${output_d}/${sample}_first_step_${job_name}.xml ]
	then
		echo "$(date) The first step of sample $sample has already been identified. Pass to next sample." >> ${params_d}/$stdout
	else
		#create .param for first step
		echo -e "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<bioml label=\"${sample}_first_step_${job_name}.xml\">\n<note type=\"heading\">Paths</note>\n<note type=\"input\" label=\"list path, default parameters\">${models_d}/${model_first_f}</note>\n<note type=\"input\" label=\"list path, taxonomy information\">${params_d}/xtandem_database_first_step_${job_name}.database</note>\n<note type=\"input\" label=\"spectrum, path\">${spectra_d}/${sample}.mzXML</note>\n<note type=\"heading\">Protein general</note>\n<note type=\"input\" label=\"protein, taxon\">usedefined</note>\n<note type=\"heading\">Output</note>\n<note type=\"input\" label=\"output, path\">${output_d}/${sample}_first_step_${job_name}.xml</note>\n</bioml>" > ${params_d}/xtandem_param_${sample}_first_step_${job_name}.param
		# launching first step
		echo -e "Arguments        = ${params_d}/xtandem_param_${sample}_first_step_${job_name}.param\nQueue\n" >> ${params_d}/htcondor_step_1_${job_name}.submit
	fi
done
echo "$(date) First step of identification is over"
echo "$(date) First step of identification is over" >> ${params_d}/$stdout

